#include <stdio.h>

extern int val ; /* valeur de l'expression booleenne */
extern yydebug ;

yyerror(s)
char *s;
{
  printf ("Erreur de syntaxe !\n ",s) ;
  exit (1) ; 
}

main ()
{

  printf("entrez une expression booleenne terminee par CTRL-D :\n") ;
  if(yyparse()==0) {
	if(val==1) 
		printf("\tle resultat est true\n");
	else 
		printf("\tle resultat est false\n");
  } 
} 
