%{

/* Ce fichier indique a l'outil "lex" comment generer l'analyseur 
   lexical du langage. Il indique donc :
	- la liste des "lexemes" (symboles terminaux de la grammaire)
	- les actions que doit effectuer l'analyseur lorsqu'il lit 
		le texte d'entree
*/

%}

espace [ \t\n]	 
bl {espace}+	

%%

{bl} ;		
true {return(True) ;}	 
TRUE {return(True) ;}
false {return(False) ;}
FALSE {return(False) ;}
"+" {return('+');}	
"*" { return('*');}
"(" {return('(');}
")" { return(')');}
. {fprintf(stderr,"Erreur lexicale ! \n");return(Erreur_lexicale);}

%%

int yywrap()
{
        return(1);
}




